Ambient occlusion post-process object holding internal states and resources.

Create with [CreateSAOFromFile] or [CreateSAOFromAssets], use with [ComputeSAO], finally call [DestroySAO] to dispose of resources when done.